/**************************************************************************/
/**MITSUBISHI**MITSUBISHI**MITSUBISHI**MITSUBISHI**MITSUBISHI**MITSUBISHI**/
/**************************************************************************/
/**************************************************************************/
/*  DISCLAIMER:                                                           */
/*  We (MITSUBISHI ELECTRIC B.V.) do not warrant that the Software is     */
/*  free from claims by a third party of copyright, patent, trademark,    */
/*  trade secret or any other intellectual property infringement.         */
/*                                                                        */
/*  Under no circumstances are we liable for any of the following:        */
/*                                                                        */
/*  1. third-party claims against you for losses or damages;              */
/*  2. loss of, or damage to, your records or data; or                    */
/*  3. economic consequential damages (including lost profits or          */
/*     savings) or incidental damages, even if we are informed of         */
/*     their possibility.                                                 */
/*                                                                        */
/*  We do not warrant uninterrupted or error free operation of the        */
/*  Software. We have no obligation to provide service, defect            */
/*  correction, or any maintenance for the Software. We have no           */
/*  obligation to supply any Software updates or enhancements to you      */
/*  even if such are or later become available.                           */
/*                                                                        */
/*  IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS.        */
/*                                                                        */
/*  THERE ARE NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING THE            */
/*  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A               */
/*  PARTICULAR PURPOSE.                                                   */
/**************************************************************************/
/**************************************************************************/
/*                                                                        */
/*       System Initialization and Service-Routines for the M3060         */
/*                                                                        */
/*       Name         :      SYS.C                                        */
/*       Date/Author  :      29.04.1997/GA                                */
/*       Change       :                                                   */
/*               29.01.1999  CA Updated for M16C62 from M16C60            */
/*                                                                        */
/**************************************************************************/

#define public extern
#include    "sfr_3062.h"
#undef public

#define public 
#include    "sys.h"
#undef public


/**************************************************************************/
/*                                                                        */
/*       Protection - system clock control register write inhibite        */
/*                                                                        */
/*       Name         :     protection_set_system_clock                   */
/*       Date/Author  :     02.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 protection_set_system_clock (void)
{   
    PRCR &= ~0x01;          // ---- ---0
                            //         +- Inhibite write to system clock
                            //            control registers 0 and 1    
                            //            0: Write inhibited
                            //            1: Write enabled
}

/**************************************************************************/
/*                                                                        */
/*       Protection - system clock control register write enable          */
/*                                                                        */
/*       Name         :     protection_clr_system_clock                   */
/*       Date/Author  :     02.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 protection_clr_system_clock (void)
{   
    PRCR |= 0x01;           // ---- ---1
                            //         +- Enable write to system clock
                            //            control registers 0 and 1    
                            //            0: Write inhibited
                            //            1: Write enabled
}

/**************************************************************************/
/*                                                                        */
/*       Protection - processor mode register write inhibite              */
/*                                                                        */
/*       Name         :     protection_set_processor_mode                 */
/*       Date/Author  :     29.04.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 protection_set_processor_mode (void)
{   
    PRCR &= ~0x02;          // ---- --0-
                            //        +-- Inhibite write to processor mode
                            //            registers 0 and 1    
                            //            0: Write inhibited
                            //            1: Write enabled
}

/**************************************************************************/
/*                                                                        */
/*       Protection - system clock control register write enable          */
/*                                                                        */
/*       Name         :     protection_clr_processor_mode                 */
/*       Date/Author  :     29.04.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 protection_clr_processor_mode (void)
{   
    PRCR |= 0x02;           // ---- --1-
                            //        +-- Enable write to processor mode     
                            //            registers 0 and 1    
                            //            0: Write inhibited
                            //            1: Write enabled
}

/**************************************************************************/
/*                                                                        */
/*       Protection - Port9 direction register write inhibite             */
/*                                                                        */
/*       Name         :     protection_set_system_clock                   */
/*       Date/Author  :     02.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 protection_set_port9 (void)
{   
    PRCR &= ~0x04;          // ---- -0--
                            //       +--- Inhibite write to Port9 direction 
                            //            register    
                            //            0: Write inhibited
                            //            1: Write enabled
}

/**************************************************************************/
/*                                                                        */
/*       Protection - Port9 direction register write enable               */
/*                                                                        */
/*       Name         :     protection_clr_system_clock                   */
/*       Date/Author  :     02.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 protection_clr_port9 (void)
{   
    PRCR |= 0x04;           // ---- -1--
                            //       +--- Enable write to Port9 direction 
                            //            register    
                            //            0: Write inhibited
                            //            1: Write enabled
}

/**************************************************************************/
/*                                                                        */
/*       Processor mode - Initialization                                  */
/*                                                                        */
/*       Name         :     processor_mode_set                            */
/*       Date/Author  :     29.04.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 processor_mode_set (void)
{   
    // Writing enablen 
    protection_clr_processor_mode ();

    //Setting Processor mode register 0
    PM0 = 0x05;             // XXXX XXXX      0x40 original
                            // |||| |||+- Processor mode bit
                            // |||| ||+-- Processor mode bit
                            // |||| ||    00: Single-chip mode
                            // |||| ||    01: Memory expansion mode
                            // |||| ||    10: Inhibited
                            // |||| ||    11: Microprocessor mode
                            // |||| |+--- R/W mode select bit
                            // |||| |     0: /RD, /BHE, /WR
                            // |||| |     1: /RD, /WRH, /WRL
                            // |||| +---- Software reset bit
                            // ||||       The device is reset when this
                            // ||||       bit is set to '1'.
                            // |||+------ Multiplexed bus space select bit
                            // ||+------- Multiplexed bus space select bit
                            // ||         00: Multiplexed bus is not used
                            // ||         01: Allocated to CS2 space
                            // ||         10: Allocated to CS1 space
                            // ||         11: Allocated to entire space
                            // |+-------- Port P40 to P43 function select bit
                            // |          0: Address output
                            // |          1: Port function (Address is no output)
                            // +----------BCLK output disable bit
                            //            0: BCLK is output
                            //            1: BCLK is not output
    PUR0 = 0x03;
    //Setting Processor mode register 1
    PM1 = 0x08;       				// X0XX 0--0
                            			// |||| |  +- Must always be set to '0'
							// |||| +---  Internal reserved area epansion bit
							// ||||       0: The same internal reserved area as
							// ||||          that of M16C60 and M16C61 group
							// ||||       1: Expands the internal RAM area and
							// ||||          and internal ROM area to 23K bytes
							// ||||          and to 256K bytes respectively
							// |||+-----  Memory area expansion bit
							// ||+------  Memory area expansion bit
							// ||         00: Normal mode
							// ||         01: Inhibited
							// ||         10: Memory area expansion mode1
							// ||         11: Memory area expansion mode2
							// |+-------- Must always be set to '0'
                            // +--------- Wait bit
                            //            0: No wait state
                            //            1: Wait state inserted

    // Writing inhibited
    protection_set_processor_mode ();
}

/**************************************************************************/
/*                                                                        */
/*       System clock - Initialization                                    */
/*                                                                        */
/*       Name         :     system_clock_set                              */
/*       Date/Author  :     05.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 system_clock_set_main_clock (void)
{   
    // Writing enablen 
    protection_clr_system_clock ();

    //Setting System clock control register 0
    CM0 = 0x58;             // XXXX XXXX
                            // |||| |||+- Clock output function select bit
                            // |||| ||+-- Clock output function select bit
                            // |||| ||    00: I/O port P57
                            // |||| ||    01: fc output
                            // |||| ||    10: f8 output
                            // |||| ||    11: f32 output
                            // |||| |+--- WAIT peripheral function clock stop bit
                            // |||| |     0: Do not stop f1, f8, f32 in
                            // |||| |        wait mode
                            // |||| |     1: Stop f1, f8, f32 in wait mode
                            // |||| +---- Xcin-Xcout drive capacity select bit
                            // ||||       0: LOW
                            // ||||       1: HIGH
                            // |||+------ Port Xc select bit
                            // |||        0: I/O port
                            // |||        1: Xcin-Xcout generation 
                            // ||+------- Main clock (Xin-Xout) stop bit
                            // ||         0: On
                            // ||         1: Off
                            // |+-------- Main clock division select bit 0
                            // |          0: CM16 and cM17 valid
                            // |          1: Division by 8 mode
                            // +--------- System clock select bit
                            //            0: Xin-Xout
                            //            1: Xcin-Xcout

    //Setting System clock control register 1
    CM1 = 0xC0;             // XXX0 000X     /*0x40*/
                            // |||| |||+- All clock stop control bit
                            // |||| |||   0: Clock on
                            // |||| |||   1: All Clock off (stop mode)
                            // |||| ||+-- Always set to '0'
                            // |||| |+--- Always set to '0'
                            // |||| +---- Always set to '0'
                            // |||+------ Always set to '0'
                            // ||+------- Xin-Xout drive capacity select bit
                            // ||         0: LOW
                            // ||         1: HIGH
                            // |+-------- Main clock division mode
                            // +--------- Main clock division mode
                            //            00: No division mode
                            //            01: Division by 2 mode
                            //            10: Division by 4 mode
                            //            11: Division by 16 mode

    // Writing inhibited
    protection_set_system_clock ();
}

/**************************************************************************/
/*                                                                        */
/*       System clock - Initialization                                    */
/*                                                                        */
/*       Name         :     system_clock_set_sub_clk                      */
/*       Date/Author  :     05.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 system_clock_set_sub_clock (void)
{   
    // Writing enablen 
    protection_clr_system_clock ();

    //Setting System clock control register 0
    CM0 = 0xD8;             // XXXX XXXX
                            // |||| |||+- Clock output function select bit
                            // |||| ||+-- Clock output function select bit
                            // |||| ||    00: I/O port P57
                            // |||| ||    01: fc output
                            // |||| ||    10: f8 output
                            // |||| ||    11: f32 output
                            // |||| |+--- WAIT peripheral function clock stop bit
                            // |||| |     0: Do not stop f1, f8, f32 in
                            // |||| |        wait mode
                            // |||| |     1: Stop f1, f8, f32 in wait mode
                            // |||| +---- Xcin-Xcout drive capacity select bit
                            // ||||       0: LOW
                            // ||||       1: HIGH
                            // |||+------ Port Xc select bit
                            // |||        0: I/O port
                            // |||        1: Xcin-Xcout generation 
                            // ||+------- Main clock (Xin-Xout) stop bit
                            // ||         0: On
                            // ||         1: Off
                            // |+-------- Main clock division select bit 0
                            // |          0: CM16 and cM17 valid
                            // |          1: Division by 8 mode
                            // +--------- System clock select bit
                            //            0: Xin-Xout
                            //            1: Xcin-Xcout

    //Setting System clock control register 1
    CM1 = 0x40;             // XXX0 000X
                            // |||| |||+- All clock stop control bit
                            // |||| |||   0: Clock on
                            // |||| |||   1: All Clock off (stop mode)
                            // |||| ||+-- Always set to '0'
                            // |||| |+--- Always set to '0'
                            // |||| +---- Always set to '0'
                            // |||+------ Always set to '0'
                            // ||+------- Xin-Xout drive capacity select bit
                            // ||         0: LOW
                            // ||         1: HIGH
                            // |+-------- Main clock division mode
                            // +--------- Main clock division mode
                            //            00: No division mode
                            //            01: Division by 2 mode
                            //            10: Division by 4 mode
                            //            11: Division by 16 mode

    // Writing inhibited
    protection_set_system_clock ();
}

/**************************************************************************/
/*                                                                        */
/*       Port 9 direction-Initialization                                  */
/*                                                                        */
/*       Name         :     port9_set                                     */
/*       Date/Author  :     05.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 port9_set (void)
{
    // Writing enablen 
    protection_clr_port9 ();

    //Setting Port 9 direction register
    PD9 = 0xFF;             // XXXX XXXX
                            // |||| |||+- Port P90 direction register
                            // |||| |||   0: Input mode
                            // |||| |||   1: Output mode
                            // |||| ||+-- Port P91 direction register
                            // |||| ||    0: Input mode
                            // |||| ||    1: Output mode
                            // |||| |+--- Port P92 direction register
                            // |||| |     0: Input mode
                            // |||| |     1: Output mode
                            // |||| +---- Port P93 direction register
                            // ||||       0: Input mode
                            // ||||       1: Output mode
                            // |||+------ Port P94 direction register
                            // |||        0: Input mode
                            // |||        1: Output mode
                            // ||+------- Port P95 direction register
                            // ||         0: Input mode
                            // ||         1: Output mode
                            // |+-------- Port P96 direction register
                            // |          0: Input mode
                            // |          1: Output mode
                            // +--------- Port P97 direction register
                            //            0: Input mode
                            //            1: Output mode

    // Writing inhibited
    protection_set_port9 ();
}

/**************************************************************************/
/*                                                                        */
/*       System clock - Low Power-Initialization                          */
/*                                                                        */
/*       Name         :     system_clock_low_power                        */
/*       Date/Author  :     05.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 system_clock_low_power (void)
{
    // Writing enablen 
    protection_clr_system_clock ();

    //Setting System clock control register 0
    CM0 &= ~0x08;           // ---- 0---
                            //      +---- Xcin-Xcout drive capacity select bit
                            //            0: LOW
                            //            1: HIGH

    //Setting System clock control register 1
    CM1 &= ~0x20;           // --00 000-
                            // |||| ||+-- Always set to '0'
                            // |||| |+--- Always set to '0'
                            // |||| +---- Always set to '0'
                            // |||+------ Always set to '0'
                            // ||+------- Xin-Xout drive capacity select bit
                            //            0: LOW
                            //            1: HIGH

    // Writing inhibited
    protection_set_system_clock ();
}

/**************************************************************************/
/*                                                                        */
/*       WATCHDOG-TIMER - Initialization                                  */
/*                                                                        */
/*       Name         :     watchdog                                      */
/*       Date/Author  :     06.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 watchdog (void)
{
    //Setting Watchdog timer control register
    WDC = 0x08;             // X00X XXXX
                            // |||| |||+- Bit  8 of watchdog timer
                            // |||| ||+-- Bit  9 of watchdog timer
                            // |||| |+--- Bit 10 of watchdog timer
                            // |||| +---- Bit 11 of watchdog timer
                            // |||+------ Bit 12 of watchdog timer
                            // ||+------- Must always be set to '0'
                            // |+-------- Must always be set to '0'
                            // +--------- Prescaler select bit
                            //            0: Divided by 16
                            //            1: Divided by 128
}

/**************************************************************************/
/*                                                                        */
/*       Software reset                                                   */
/*                                                                        */
/*       Name         :     software_reset                                */
/*       Date/Author  :     06.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 software_reset (void)
{   
    // Writing enablen 
    protection_clr_processor_mode ();

    //Setting Processor mode register 0
    PM0 |= 0x08;            // ---- 1---
                            // |||| +---- Software reset bit
                            // ||||       The device is reset when this
                            // ||||       bit is set to '1'.
}

/**************************************************************************/
/*                                                                        */
/*       Stop mode                                                        */
/*                                                                        */
/*       Name         :     stop_mode                                     */
/*       Date/Author  :     05.05.1997/GA                                 */
/*       Parameter    :                                                   */
/*       Return       :                                                   */
/*                                                                        */
/**************************************************************************/
void fct_loc_1 stop_mode (void)
{
    // Writing enablen 
    protection_clr_system_clock ();

    //Setting System clock control register 1
    CM1 |= 0x01;            // ---0 0001
                            //    | |||+- All clock stop control bit
                            //    | |||   0: Clock on
                            //    | |||   1: All Clock off (stop mode)
                            //    | ||+-- Always set to '0'
                            //    | |+--- Always set to '0'
                            //    | +---- Always set to '0'
                            //    +------ Always set to '0'

    // Writing inhibited
    protection_set_system_clock ();
}


